==> quarkus-core-deployment-3.1.2.Final-sources.jar: io/quarkus/deployment/dev/testing/TestConfig$$accessor.java <==
package io.quarkus.deployment.dev.testing;
public final class TestConfig$$accessor {
    private TestConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_nativeImageProfile(Object __instance) {
        return ((TestConfig)__instance).nativeImageProfile;
    }
    @SuppressWarnings("unchecked")
    public static void set_nativeImageProfile(Object __instance, Object nativeImageProfile) {
        ((TestConfig)__instance).nativeImageProfile = (String)nativeImageProfile;
    }
    @SuppressWarnings("unchecked")
    public static Object get_integrationTestProfile(Object __instance) {
        return ((TestConfig)__instance).integrationTestProfile;
    }
    @SuppressWarnings("unchecked")
    public static void set_integrationTestProfile(Object __instance, Object integrationTestProfile) {
        ((TestConfig)__instance).integrationTestProfile = (String)integrationTestProfile;
    }
    @SuppressWarnings("unchecked")
    public static Object get_profile(Object __instance) {
        return ((TestConfig)__instance).profile;
    }
    @SuppressWarnings("unchecked")
    public static void set_profile(Object __instance, Object profile) {
        ((TestConfig)__instance).profile = (io.quarkus.deployment.dev.testing.TestConfig.Profile)profile;
    }
    @SuppressWarnings("unchecked")
    public static Object get_container(Object __instance) {
        return ((TestConfig)__instance).container;
    }
    @SuppressWarnings("unchecked")
    public static void set_container(Object __instance, Object container) {
        ((TestConfig)__instance).container = (io.quarkus.deployment.dev.testing.TestConfig.Container)container;
    }
    @SuppressWarnings("unchecked")
    public static Object get_argLine(Object __instance) {
        return ((TestConfig)__instance).argLine;
    }
    @SuppressWarnings("unchecked")
    public static void set_argLine(Object __instance, Object argLine) {
        ((TestConfig)__instance).argLine = (java.util.Optional<java.util.List<String>>)argLine;
    }
    @SuppressWarnings("unchecked")
    public static Object get_waitTime(Object __instance) {
        return ((TestConfig)__instance).waitTime;
    }
    @SuppressWarnings("unchecked")
    public static void set_waitTime(Object __instance, Object waitTime) {
        ((TestConfig)__instance).waitTime = (java.time.Duration)waitTime;
    }
    @SuppressWarnings("unchecked")
    public static Object get_hangDetectionTimeout(Object __instance) {
        return ((TestConfig)__instance).hangDetectionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_hangDetectionTimeout(Object __instance, Object hangDetectionTimeout) {
        ((TestConfig)__instance).hangDetectionTimeout = (java.time.Duration)hangDetectionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_type(Object __instance) {
        return ((TestConfig)__instance).type;
    }
    @SuppressWarnings("unchecked")
    public static void set_type(Object __instance, Object type) {
        ((TestConfig)__instance).type = (TestType)type;
    }
    @SuppressWarnings("unchecked")
    public static Object get_classClonePattern(Object __instance) {
        return ((TestConfig)__instance).classClonePattern;
    }
    @SuppressWarnings("unchecked")
    public static void set_classClonePattern(Object __instance, Object classClonePattern) {
        ((TestConfig)__instance).classClonePattern = (String)classClonePattern;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_onlyTestApplicationModule(Object __instance) {
        return ((TestConfig)__instance).onlyTestApplicationModule;
    }
    @SuppressWarnings("unchecked")
    public static void set_onlyTestApplicationModule(Object __instance, boolean onlyTestApplicationModule) {
        ((TestConfig)__instance).onlyTestApplicationModule = onlyTestApplicationModule;
    }
}

==> quarkus-core-deployment-3.2.9.Final-sources.jar: io/quarkus/deployment/dev/testing/TestConfig$$accessor.java <==
package io.quarkus.deployment.dev.testing;
public final class TestConfig$$accessor {
    private TestConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_nativeImageProfile(Object __instance) {
        return ((TestConfig)__instance).nativeImageProfile;
    }
    @SuppressWarnings("unchecked")
    public static void set_nativeImageProfile(Object __instance, Object nativeImageProfile) {
        ((TestConfig)__instance).nativeImageProfile = (String)nativeImageProfile;
    }
    @SuppressWarnings("unchecked")
    public static Object get_integrationTestProfile(Object __instance) {
        return ((TestConfig)__instance).integrationTestProfile;
    }
    @SuppressWarnings("unchecked")
    public static void set_integrationTestProfile(Object __instance, Object integrationTestProfile) {
        ((TestConfig)__instance).integrationTestProfile = (String)integrationTestProfile;
    }
    @SuppressWarnings("unchecked")
    public static Object get_profile(Object __instance) {
        return ((TestConfig)__instance).profile;
    }
    @SuppressWarnings("unchecked")
    public static void set_profile(Object __instance, Object profile) {
        ((TestConfig)__instance).profile = (io.quarkus.deployment.dev.testing.TestConfig.Profile)profile;
    }
    @SuppressWarnings("unchecked")
    public static Object get_container(Object __instance) {
        return ((TestConfig)__instance).container;
    }
    @SuppressWarnings("unchecked")
    public static void set_container(Object __instance, Object container) {
        ((TestConfig)__instance).container = (io.quarkus.deployment.dev.testing.TestConfig.Container)container;
    }
    @SuppressWarnings("unchecked")
    public static Object get_argLine(Object __instance) {
        return ((TestConfig)__instance).argLine;
    }
    @SuppressWarnings("unchecked")
    public static void set_argLine(Object __instance, Object argLine) {
        ((TestConfig)__instance).argLine = (java.util.Optional<java.util.List<String>>)argLine;
    }
    @SuppressWarnings("unchecked")
    public static Object get_env(Object __instance) {
        return ((TestConfig)__instance).env;
    }
    @SuppressWarnings("unchecked")
    public static void set_env(Object __instance, Object env) {
        ((TestConfig)__instance).env = (java.util.Map<String, String>)env;
    }
    @SuppressWarnings("unchecked")
    public static Object get_waitTime(Object __instance) {
        return ((TestConfig)__instance).waitTime;
    }
    @SuppressWarnings("unchecked")
    public static void set_waitTime(Object __instance, Object waitTime) {
        ((TestConfig)__instance).waitTime = (java.time.Duration)waitTime;
    }
    @SuppressWarnings("unchecked")
    public static Object get_hangDetectionTimeout(Object __instance) {
        return ((TestConfig)__instance).hangDetectionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_hangDetectionTimeout(Object __instance, Object hangDetectionTimeout) {
        ((TestConfig)__instance).hangDetectionTimeout = (java.time.Duration)hangDetectionTimeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_type(Object __instance) {
        return ((TestConfig)__instance).type;
    }
    @SuppressWarnings("unchecked")
    public static void set_type(Object __instance, Object type) {
        ((TestConfig)__instance).type = (TestType)type;
    }
    @SuppressWarnings("unchecked")
    public static Object get_classClonePattern(Object __instance) {
        return ((TestConfig)__instance).classClonePattern;
    }
    @SuppressWarnings("unchecked")
    public static void set_classClonePattern(Object __instance, Object classClonePattern) {
        ((TestConfig)__instance).classClonePattern = (String)classClonePattern;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_onlyTestApplicationModule(Object __instance) {
        return ((TestConfig)__instance).onlyTestApplicationModule;
    }
    @SuppressWarnings("unchecked")
    public static void set_onlyTestApplicationModule(Object __instance, boolean onlyTestApplicationModule) {
        ((TestConfig)__instance).onlyTestApplicationModule = onlyTestApplicationModule;
    }
}
